
AGESpec
==================

Spectroscopy with the AS5 Atomic Genesis Explorer (AGE)

Authors
-------

- **David Nidever** (Montana State University)
  
Installation
------------

To install the latest version::

    pip install git+https://github.com/dnidever/agespec


License
-------

.. image:: http://img.shields.io/badge/license-MIT-blue.svg?style=flat
        :target: https://github.com/dnidever/agespec/blob/main/LICENSE
